@@ -1,7 +1,7 @@
 export CVS_RSH=ssh
-export VN=0.29.2
+export VN=0.31
 export VER=tork-$VN
-export TAG=v0_29_2
+export TAG=v0_31
 cd ..
 TOPDIR=$PWD
 cd TorkReleases
