@@ -1,5 +1,5 @@
 /***************************************************************************
- ** $Id: main.cpp,v 1.59 2008/08/21 11:50:14 hoganrobert Exp $
+ ** $Id: main.cpp,v 1.60 2008/12/14 14:50:05 hoganrobert Exp $
  *   Copyright (C) 2006 - 2008 Robert Hogan                                *
  *   robert@roberthogan.net                                                *
  *                                                                         *
@@ -38,7 +38,7 @@ static const char description[] =
               "quality, suitability or anything else.");
 
 static const char version[] = "";
-static const char title[] = "TorK 0.29.2";
+static const char title[] = "TorK 0.31";
 
 static KCmdLineOptions options[] =
 {
@@ -78,6 +78,7 @@ int main(int argc, char **argv)
     about.addCredit( "Emre Aladag, Inanc Yildirgan, Mustafa Gunay, Ertugrul Erata", I18N_NOOP("Turkish Translation"), 0);
     about.addCredit( "Liu Songhe", I18N_NOOP("Chinese Translation"), "shuizhuyuanluo@126.com");
     about.addCredit( "Marek Stopka", I18N_NOOP("Czech Translation"), "marekstopka@gmail.com");
+    about.addCredit( "Hans-J. Ullrich", I18N_NOOP("German Translation"), "hans.ullrich@loop.de");
     about.addCredit( "Max Urgel", I18N_NOOP("German Translation"), "bitwisser@googlemail.com");
     about.addCredit( "Daniel Berthereau", I18N_NOOP("French Translation"),
                      "Daniel.Berthereau@free.fr");
