@@ -1,10 +1,10 @@
 /***************************************************************************
-** $Id: questions.h,v 1.31 2008/06/08 21:05:11 hoganrobert Exp $
+** $Id: questions.h,v 1.35 2008/08/14 21:17:39 hoganrobert Exp $
  *
  *   Based on config method in Tor
  *
- *   Copyright (C) 2006 by Robert Hogan   *
- *   robert@roberthogan.net   *
+ *   Copyright (C) 2006 - 2008 Robert Hogan                                *
+ *   robert@roberthogan.net                                                *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -191,6 +191,21 @@ static question_t _tork_questions[] = {
         (&tork::dummyAction),
         (&tork::readEavesdropping)),
 
+    MSG("privoxynotrunning", 
+        i18n("Are you sure your Privacy Proxy is running?"),
+        i18n("TorK tested your configured privacy proxy and it does not seem "
+              "to be running."),
+        "",
+        i18n("Would you like TorK to use Privoxy instead?"),
+        DISPLAY_NONE,
+        true,
+        false,
+        i18n("Show Security Warnings"),
+        "tork_alert",
+        (&tork::showSecurityWarnings),
+        (&tork::dummyAction),
+        (&tork::letTorKManagePrivoxy)),
+
     MSG("privoxycouldntstart", 
         i18n("TorK couldn't start your Privacy Proxy!"),
         i18n("This may be because you have configured it to launch at system startup. If that is the case, and you have reason to believe it is configured to listen to Tor, then just click 'No' and take a look at the 'Konqueror' settings in the configuration dialog."),
@@ -332,19 +347,33 @@ static question_t _tork_questions[] = {
         (&tork::dummyAction),
         (&tork::stopTor)),
 
-    MSG("passwordlost", 
-        i18n("You used the wrong password to connect to Tor!"),
-        i18n("Maybe TorK crashed and lost the temporary password for connecting to Tor?"),
+    MSG("terminatetor",
+        i18n("Tor will close gracefully in 30 seconds!"),
+        i18n("The delay allows other Tor users to re-route their connections to other servers."),
         "",
-        i18n("If Tor is running locally TorK can reset Tor and then retry the connection. Would you like TorK to try this (<b>it will need to ask for your root password</b>)? "),
+        i18n("Would you like to go ahead and shut down immediately? "),
         DISPLAY_NONE,
         true,
         true,
         i18n("Show TorK Feedback"),
-        "tork_alert",
+        "tork_help",
         (&tork::showGuideQuestions),
         (&tork::dummyAction),
-        (&tork::resetTor)),
+        (&tork::stopTor)),
+
+     MSG("passwordlost",
+         i18n("You used the wrong password to connect to Tor!"),
+         i18n("Maybe TorK crashed and lost the temporary password for connecting to Tor?"),
+         "",
+         i18n("If Tor is running locally TorK can reset Tor and then retry the connection. Would you like TorK to try this (<b>it will need to ask for your root password</b>)? "),
+         DISPLAY_NONE,
+         true,
+         true,
+         i18n("Show TorK Feedback"),
+         "tork_alert",
+         (&tork::showGuideQuestions),
+         (&tork::dummyAction),
+         (&tork::resetTor)),
 
 
   { NULL, NULL, NULL, "", NULL, DISPLAY_NONE, false, false, NULL, NULL,
