@@ -1,5 +1,5 @@
 /****************************************************************************
- ** $Id: torclient.cpp,v 1.132 2008/08/22 13:37:37 hoganrobert Exp $
+ ** $Id: torclient.cpp,v 1.136 2009/01/29 21:34:39 hoganrobert Exp $
  *   Copyright (C) 2006 - 2008 Robert Hogan                                *
  *   robert@roberthogan.net                                                *
  *                                                                         *
@@ -189,7 +189,7 @@ TorClient::TorClient( const QString &host, Q_UINT16 port )
 
 }
 
-void TorClient::configureServer( )
+void TorClient::configureServer( int orPort, int dirPort)
 {
 
     sendToServer(QString("SETCONF ContactInfo=%1").arg(TorkConfig::contactInfo())) ;
@@ -208,13 +208,13 @@ void TorClient::configureServer( )
       //telling us that one cannot be set without the other.
       sendToServer(QString("SETCONF ORPort=%1 "
                            "ORListenAddress=0.0.0.0:%2")
-                           .arg(TorkConfig::oRPort())
+                           .arg(orPort)
                            .arg(TorkConfig::oRListenAddress())) ;
       //We send the dirport configs together to avoid error messages from Tor
       //telling us that one cannot be set without the other.
       sendToServer(QString("SETCONF DIRPort=%1 "
                            "DIRListenAddress=0.0.0.0:%2")
-                           .arg(TorkConfig::dirPort())
+                           .arg(dirPort)
                            .arg(TorkConfig::dirListenAddress())) ;
       sendToServer(QString("SETCONF BridgeRelay=%1").arg(TorkConfig::bridgeRelay())) ;
     }else{
@@ -458,6 +458,7 @@ void TorClient::bandwidth()
     sendToServer("SETEVENTS EXTENDED CIRC  STREAM  ORCONN  NOTICE "
                   "WARN  ERR  ADDRMAP BW STREAM_BW NS STATUS_GENERAL "
                   "STATUS_CLIENT STATUS_SERVER GUARD");
+    sendToServer(QString("SETCONF __ReloadTorrcOnSIGHUP=0"));
 
 
 }
@@ -1206,9 +1207,6 @@ void TorClient::applySettingsToRunningTor()
     sendToServer(QString("GETCONF ExitNodes")) ;
     sendToServer(QString("GETCONF EntryNodes")) ;
 
-    //We're setting the server config here. The server values aren't used if we're 'client only'.
-    //It needs to be called so that the sys tray icon reflects our choice of server vs client.
-    configureServer();
 }
 
 bool TorClient::elementShouldBeUsed(const KConfigSkeletonItem* it)
@@ -1387,6 +1385,19 @@ bool TorClient::noSpecialProcessing(const KConfigSkeletonItem* it)
         return false;
     }
 
+    if ((*it).name() == "MapAddress"){
+
+        QStringList maps = TorkConfig::mapAddress();
+        for ( QStringList::Iterator it = (maps).begin();
+              it != (maps).end(); it++ )
+        {
+            if ((*it).isEmpty())
+                continue;
+            ( sendToServer(QString("SETCONF MapAddress=%2").arg((*it)))) ;
+        }
+        return false;
+    }
+    
     if ((!TorkConfig::fascistFirewall()) && ((*it).name() == "ReachableAddresses")){
         ( sendToServer(QString("SETCONF ReachableAddresses="))) ;
         return false;
@@ -1431,7 +1442,7 @@ void TorClient::parseDirStatus(const QString &info)
                 storeServer(ds_server,ds_identity);
     
             ds_statuses = info;
-            emit updateServerStatus(ds_ip, ds_identity, ds_server, ds_statuses, m_firstloadcomplete);
+            emit updateServerStatus(ds_ip, ds_identity, ds_server, ds_statuses);
         }
     }
 
