@@ -1,5 +1,5 @@
 /***************************************************************************
- ** $Id: torkview.cpp,v 1.122 2008/08/20 16:49:31 hoganrobert Exp $
+ ** $Id: torkview.cpp,v 1.123 2008/12/08 19:49:28 hoganrobert Exp $
  *   Copyright (C) 2006 - 2008 Robert Hogan                                *
  *   robert@roberthogan.net                                                *
  *                                                                         *
@@ -1279,9 +1279,12 @@ void torkView::reportBW(int secs)
                          kbstx);
 }
 
-unsigned long torkView::readInterfaceNumValue(QString interface, const char* name) {
+unsigned long torkView::readInterfaceNumValue(QString interface,
+                                              const char* name) {
 	// stdio functions appear to be more fast than QFile?
 	FILE* fp = fopen((interface+"/statistics/"+name).latin1(), "r");
+	if (!fp)
+      return 0;
 	long retval;
 	fscanf(fp, "%lu", &retval);
 	fclose(fp);
@@ -1307,16 +1310,14 @@ void torkView::activeServersUpdated( const QStringList &servers)
 
 }
 
-void torkView::serverStatusUpdated(const QString &ip,const QString &fp, const QString &server,const QString &statuses, bool update )
+void torkView::serverStatusUpdated(const QString &ip,const QString &fp,
+                                   const QString &server, const QString &statuses)
 {
     QListViewItem* tm;
     
-    if (update){
-        if (!( tm = torservers[fp]))
-            tm = new QListViewItem(serverList, "", (server), fp, statuses);
-    }else{
-        tm = new QListViewItem(serverList, "", (server), fp, statuses);
-        torservers[fp] = tm;
+    if (!(tm = torservers[fp])){
+      tm = new QListViewItem(serverList, "", (server), fp, statuses);
+      torservers[fp] = tm;
     }
 
     QString cc;
