@@ -1,6 +1,6 @@
 /***************************************************************************
- * $Id: torkview_base.ui.h,v 1.42 2008/04/14 11:15:53 hoganrobert Exp $
- *   Copyright (C) 2006 by Robert Hogan                                    *
+ * $Id: torkview_base.ui.h,v 1.47 2008/07/31 19:56:28 hoganrobert Exp $
+ *   Copyright (C) 2006 - 2008 Robert Hogan                                *
  *   robert@roberthogan.net                                                *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -22,6 +22,7 @@
 #include <qtooltip.h>
 #include <qpopupmenu.h>
 #include <kdebug.h>
+#include <qclipboard.h>
 
 #include <kapplication.h>
 #include <kiconloader.h>
@@ -38,6 +39,11 @@
 
 bool m_LeaveStreamsUnattached;
 
+typedef QMap<QString, QListViewItem*> ResolveMap;
+ResolveMap resolveMap;
+typedef QMap<QListViewItem*, int > ResolveColMap;
+ResolveColMap resolveColMap;
+
 void torkview_base::init()
 {
 
@@ -521,3 +527,117 @@ void torkview_base::ShowHostNames_toggled( bool safe)
 {
   emit safeLogging(!safe);
 }
+
+void torkview_base::copyLogLines()
+{
+  QClipboard *cb = QApplication::clipboard();
+  QString logLines;
+
+  QListViewItemIterator it(infoList, QListViewItemIterator::Selected | QListViewItemIterator::Visible);
+  while ( it.current() ) {
+    // Copy text into the clipboard
+    logLines.append((*it)->text(0));
+    logLines.append("\t");
+    logLines.append((*it)->text(2));
+    logLines.append("\t");
+    logLines.append((*it)->text(3));
+    logLines.append("\n");
+
+     ++it;
+  }
+
+  cb->setText( logLines, QClipboard::Clipboard );
+
+}
+
+void torkview_base::selectAllLogLines()
+{
+  QListViewItemIterator it(infoList);
+  while ( it.current() ) {
+     (*it)->setSelected(true);
+     ++it;
+  }
+  infoList->repaint();
+}
+
+void torkview_base::infoList_contextMenuRequested( QListViewItem *, const QPoint &point, int )
+{
+    QPopupMenu *menu = new QPopupMenu( infoList );
+
+    menu->clear();
+    menu->insertItem( SmallIconSet("copy"), "Copy", this, SLOT(copyLogLines()) );
+    menu->insertSeparator();
+    menu->insertItem( "Select All", this, SLOT(selectAllLogLines()) );
+    menu->popup( point );
+
+}
+
+
+void torkview_base::TorTraffic_contextMenuRequested( QListViewItem *, const QPoint &point, int )
+{
+
+    QPopupMenu *menu = new QPopupMenu( TorTraffic );
+
+    menu->clear();
+    menu->insertItem( SmallIconSet("help"), "Resolve Hostname/Address", this, SLOT(queryHostName()) );
+    menu->popup( point );
+
+}
+
+void torkview_base::queryHostName()
+{
+    QRegExp rx("[0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3}");
+    QRegExp rx2("[^:]+");
+
+    QListView *tmpList;
+    QString addressToResolve;
+    QString addressToMatch;
+
+    if (TorTraffic->hasFocus()) {
+      tmpList = TorTraffic;
+    }else{
+      tmpList = NonTorTraffic;
+    }
+
+    int col = (tmpList == TorTraffic) ? 2 : 1;
+    rx.search(tmpList->selectedItem()->text(col));
+    QString tmp = rx.cap(0);
+    rx2.search(tmpList->selectedItem()->text(col));
+    QString tmp2 = rx2.cap(0);
+
+    if (!tmp.isEmpty()){
+        addressToMatch = QString("REVERSE[%1]").arg(tmp);
+        addressToResolve = tmp;
+    }else{
+        addressToResolve = tmp2;
+        addressToMatch = tmp2;
+    }
+
+    resolveMap[addressToMatch] = tmpList->selectedItem();
+    resolveColMap[tmpList->selectedItem()] = col;
+
+    emit resolveAddress(addressToResolve);
+}
+
+void torkview_base::resolvedAddress(const QString &info)
+{
+    QString type = info.section(" ",0,0);
+    QString address = info.section(" ",1,1);
+
+    if (resolveMap[type]){
+        int column = resolveColMap[resolveMap[type]];
+        resolveMap[type]->setText(column,address);
+        resolveMap.erase(type);
+        resolveColMap.erase(resolveMap[type]);
+    }
+}
+
+void torkview_base::NonTorTraffic_contextMenuRequested( QListViewItem *, const QPoint &point, int )
+{
+    QPopupMenu *menu = new QPopupMenu( NonTorTraffic );
+
+    menu->clear();
+    menu->insertItem( SmallIconSet("help"), "Resolve Hostname/Address", this, SLOT(queryHostName()) );
+    menu->popup( point );
+
+}
