@@ -70,6 +70,7 @@ int (*realconnect)(CONNECT_SIGNATURE);
 static int (*realselect)(SELECT_SIGNATURE);
 static int (*realpoll)(POLL_SIGNATURE);
 int (*realclose)(CLOSE_SIGNATURE);
+static int (*realgetpeername)(GETPEERNAME_SIGNATURE);
 static struct parsedfile *config;
 static struct connreq *requests = NULL;
 static int suid = 0;
@@ -81,6 +82,7 @@ int connect(CONNECT_SIGNATURE);
 int select(SELECT_SIGNATURE);
 int poll(POLL_SIGNATURE);
 int close(CLOSE_SIGNATURE);
+int getpeername(GETPEERNAME_SIGNATURE);
 #ifdef USE_SOCKS_DNS
 int res_init(void);
 #endif
@@ -126,14 +128,15 @@ void tsocks_init(void) {
 	/* most programs that are run won't use our services, so     */
 	/* we do our general initialization on first call            */
 
-   /* Determine the logging level */
-   suid = (getuid() != geteuid());
+	/* Determine the logging level */
+	suid = (getuid() != geteuid());
 
 #ifndef USE_OLD_DLSYM
 	realconnect = dlsym(RTLD_NEXT, "connect");
 	realselect = dlsym(RTLD_NEXT, "select");
 	realpoll = dlsym(RTLD_NEXT, "poll");
 	realclose = dlsym(RTLD_NEXT, "close");
+	realgetpeername = dlsym(RTLD_NEXT, "getpeername");
 	#ifdef USE_SOCKS_DNS
 	realresinit = dlsym(RTLD_NEXT, "res_init");
 	#endif
@@ -393,8 +396,10 @@ int select(SELECT_SIGNATURE) {
 
    /* If we're not currently managing any requests we can just 
     * leave here */
-   if (!requests)
+   if (!requests) {
+      show_msg(MSGDEBUG, "No requests waiting, calling real select\n");
       return(realselect(n, readfds, writefds, exceptfds, timeout));
+   }
 
    get_environment();
 
@@ -749,6 +754,50 @@ int close(CLOSE_SIGNATURE) {
    return(rc);
 }
 
+/* If we are not done setting up the connection yet, return
+ * -1 and ENOTCONN, otherwise call getpeername
+ *
+ * This is necessary since some applications, when using non-blocking connect,
+ * (like ircII) use getpeername() to find out if they are connected already.
+ *
+ * This results in races sometimes, where the client sends data to the socket
+ * before we are done with the socks connection setup.  Another solution would
+ * be to intercept send().
+ * 
+ * This could be extended to actually set the peername to the peer the
+ * client application has requested, but not for now.
+ *
+ * PP, Sat, 27 Mar 2004 11:30:23 +0100
+ */
+int getpeername(GETPEERNAME_SIGNATURE) {
+   struct connreq *conn;
+   int rc;
+
+    if (realgetpeername == NULL) {
+        show_msg(MSGERR, "Unresolved symbol: getpeername\n");
+        return(-1);
+    }
+
+   show_msg(MSGDEBUG, "Call to getpeername for fd %d\n", __fd);
+
+
+   rc = realgetpeername(__fd, __name, __namelen);
+   if (rc == -1)
+       return rc;
+
+   /* Are we handling this connect? */
+   if ((conn = find_socks_request(__fd, 1))) {
+       /* While we are at it, we might was well try to do something useful */
+       handle_request(conn);
+
+       if (conn->state != DONE) {
+           errno = ENOTCONN;
+           return(-1);
+       }
+   }
+   return rc;
+}
+
 static struct connreq *new_socks_request(int sockid, struct sockaddr_in *connaddr, 
                                          struct sockaddr_in *serveraddr, 
                                          struct serverent *path) {
@@ -898,7 +947,7 @@ static int connect_server(struct connreq *conn) {
                     sizeof(conn->serveraddr));
 
    show_msg(MSGDEBUG, "Connect returned %d, errno is %d\n", rc, errno); 
-	if (rc) {
+   if (rc) {
       if (errno != EINPROGRESS) {
          show_msg(MSGERR, "Error %d attempting to connect to SOCKS "
                   "server (%s)\n", errno, strerror(errno));
@@ -1121,6 +1170,10 @@ static int recv_buffer(struct connreq *conn) {
       if (rc > 0) {
          conn->datadone += rc;
          rc = 0;
+      } else if (rc == 0) {
+         show_msg(MSGDEBUG, "Peer has shutdown but we only read %d of %d bytes.\n",
+            conn->datadone, conn->datalen);
+         rc = ENOTCONN; /* ENOTCONN seems like the most fitting error message */
       } else {
          if (errno != EWOULDBLOCK)
             show_msg(MSGDEBUG, "Read failed, %s\n", strerror(errno));
