@@ -1,5 +1,5 @@
 /***************************************************************************
- * $Id: update.cpp,v 1.25 2008/08/20 16:49:31 hoganrobert Exp $
+ * $Id: update.cpp,v 1.26 2008/12/08 19:39:02 hoganrobert Exp $
  *   Copyright (C) 2006 - 2008 Robert Hogan                                *
  *   robert@roberthogan.net                                                *
  *                                                                         *
@@ -329,11 +329,11 @@ void TorkUpdate::checkForNewTorkDirectly()
 }
 
 
-void TorkUpdate::checkForNewTorDirectly()
+void TorkUpdate::checkForNewTorDirectly(bool alpha)
 {
 
     checkingDirectly = true;
-
+    m_alpha=alpha;
     highestsofarnumeric = 0;
     tork_url = "http://torproject.org/dist/";
 
@@ -362,6 +362,7 @@ void TorkUpdate::completedSearchForUpdates(const QString &component, const QStri
 
     double currentversion;
 
+
     if (component == "Tork")
         currentversion = VERSION_TORK;
     else{
@@ -384,6 +385,7 @@ void TorkUpdate::completedSearchForUpdates(const QString &component, const QStri
         KMessageBox::information (this,i18n("Your installation of %1 is already up-to-date!").arg(component));
     }
     checkingDirectly = false;
+    m_alpha=false;
 //     tork_options->setEnabled(true);
 //     tork_options->setEnabled(true);
 
@@ -591,9 +593,9 @@ void TorkUpdate::getVersionFromLink( const DOM::Node &n )
                           .replace("dante-","");
         
         QString rawversion = version;
-
-        version.remove("-alpha").remove("-beta").remove("-rc");
-
+        if (m_alpha) {
+          version.remove("-alpha").remove("-beta").remove("-rc");
+        }
         numericversion = numericizeVersion(version);
 
         if (numericversion > highestsofarnumeric){
